package com.haulmont.vaadin.sample;

import com.vaadin.data.Item;
import com.vaadin.data.util.IndexedContainer;
import com.vaadin.server.Sizeable;
import com.vaadin.server.VaadinRequest;
import com.vaadin.ui.*;

public class SampleVaadinUI extends UI {

    int itemCounter = 0;
    IndexedContainer container;

    @Override
    protected void init(VaadinRequest request) {
        VerticalLayout layout = new VerticalLayout();
        layout.setSizeFull();

        Table table = new Table();
        table.setSizeFull();
        table.setSelectable(true);
        table.setImmediate(true);

        container = new IndexedContainer();
        container.addContainerProperty("1", Integer.class, null);
        container.addContainerProperty("2", Integer.class, null);

        Item item = container.addItem(itemCounter);
        item.getItemProperty("1").setValue(itemCounter * 10 + 1);
        item.getItemProperty("2").setValue(itemCounter * 10 + 2);

        itemCounter++;

        table.setContainerDataSource(container);
        table.setVisibleColumns("1", "2");
        table.setColumnReorderingAllowed(true);
        table.setColumnCollapsingAllowed(true);

        table.setColumnHeaders("1", "2");
        table.addGeneratedColumn("2", new Table.ColumnGenerator() {
            public Object generateCell(Table source, Object itemId, Object columnId) {
                GridLayout grid = new GridLayout();
                grid.setWidth(100, Sizeable.Unit.PERCENTAGE);

                grid.setColumns(2);
                grid.setRows(1);

                TextField tx1 = new TextField("Some cool text:");
                tx1.setWidth(100, Sizeable.Unit.PERCENTAGE);

                TextField tx2 = new TextField("Buggy text:");
                tx2.setWidth(100, Sizeable.Unit.PERCENTAGE);

                grid.addComponent(tx1);
                grid.addComponent(tx2);

                return grid;
            }
        });

        HorizontalLayout buttonsLayout = new HorizontalLayout();
        buttonsLayout.setWidth(100, Sizeable.Unit.PERCENTAGE);

        Button addButton = new Button("Add");
        addButton.setSizeUndefined();
        addButton.addClickListener(new Button.ClickListener() {
            public void buttonClick(Button.ClickEvent event) {
                Item newItem = container.addItem(itemCounter);
                newItem.getItemProperty("1").setValue(itemCounter * 10 + 1);
                newItem.getItemProperty("2").setValue(itemCounter * 10 + 2);

                itemCounter++;
            }
        });

        buttonsLayout.addComponent(addButton);

        layout.addComponent(buttonsLayout);
        layout.addComponent(table);

        layout.setExpandRatio(table, 1f);
        setContent(layout);
    }
}